idlehomescreen/xmluirendering/uiengine/inc/xnviewdata.h
branchRCL_3
changeset 23 7be2816dbabd
parent 12 9674c1a575e9
--- a/idlehomescreen/xmluirendering/uiengine/inc/xnviewdata.h	Tue Apr 27 16:26:12 2010 +0300
+++ b/idlehomescreen/xmluirendering/uiengine/inc/xnviewdata.h	Tue May 11 16:02:39 2010 +0300
@@ -98,16 +98,22 @@
      * @see CXnPluginData           
      */    
     void PopupNodesL( RPointerArray< CXnNode >& aList ) const;
-            
+
+    /**
+     * @see CXnPluginData           
+     */        
+    void NotifyPublisherReadyL();
+    
 public:   
     // New functions
     
     /**
      * Sets viewdata to active/ not active
      * 
      * @param aActive ETrue active, EFalse not active    
      */
-    void SetActive( TBool aActive );
+    TInt SetActive( TBool aActive );
     
     /**
      * Returns if active or not
@@ -205,7 +211,7 @@
     /**
      * Loads publishers to this view           
      */
-    void LoadPublishers();    
+    void LoadPublishers( TInt aReason );    
                    
     /**
      * Destroys all publishers in this view
@@ -213,25 +219,16 @@
      * @param aReason Destroy reason
      */
     void DestroyPublishers( TInt aReason );
-    
-private:
-    // new functions
-    
-    static TInt DoLoadPublishersL( TAny* aAny );
-    
-    void DoDestroyPublishersL( TInt aReason );
-    
+            
 private:
     // data                              
     
     /** Pointer to wallpaper image, Owned */    
     CFbsBitmap* iBgImage;    
     /** Path of the wallpaper image, including filename */    
-    HBufC* iBgImagePath;            
-    /** Publisher load index */
-    TInt iLoadIndex;    
-    /** Flag to indicate whether content removed error should be shown */
-    TBool iShowContentRemoved;    
+    HBufC* iBgImagePath;    
+    /** Load error code */
+    TInt iLoadError;
     };
 
 #include "xnviewdata.inl"
@@ -98,16 +98,22 @@
      * Sets viewdata to active/ not active
      * 
-     * @param aActive ETrue active, EFalse not active    
+     * @param aActive ETrue active, EFalse not active
+     * @return Activation Error code    
      */